@@ -258,7 +258,150 @@ def test_github_issue_55():
               'return configs;\n}\n}</pre>')
     assert result == expect
 
-def test_issue_56():
+def test_github_issue_56():
+    """Empty description lists throw error"""
     result = textile.textile("- :=\n-")
     expect = '<dl>\n</dl>'
     assert result == expect
+
+def test_github_pull_61():
+    """Fixed code block multiline encoding on quotes/span"""
+    test = '''bc.. This is some TEXT inside a "Code BLOCK"
+
+{
+  if (JSON) {
+
+    return {"JSON":"value"}
+  }
+}
+
+Back to 10-4 CAPS 
+
+p.. Some multiline Paragragh
+
+Here is some output!!! "Some" CAPS'''
+
+    expect = '''<pre><code>This is some TEXT inside a &quot;Code BLOCK&quot;
+
+{
+  if (JSON) {
+
+    return {&quot;JSON&quot;:&quot;value&quot;}
+  }
+}
+
+Back to 10-4 CAPS </code></pre>
+
+<p>Some multiline Paragragh</p>
+
+<p>Here is some output!!! &#8220;Some&#8221; <span class="caps">CAPS</span></p>'''
+    t = textile.Textile()
+    result = t.parse(test)
+    assert result == expect
+
+def test_github_pull_62():
+    """Fix for paragraph multiline, only last paragraph is rendered
+    correctly"""
+    test = '''p.. First one 'is'
+
+ESCAPED "bad"
+
+p.. Second one 'is'
+
+
+
+ESCAPED "bad"
+
+p.. Third one 'is'
+
+ESCAPED "bad"
+
+p.. Last one 'is'
+
+ESCAPED "good" test'''
+
+    expect = '''<p>First one &#8216;is&#8217;</p>
+
+<p><span class="caps">ESCAPED</span> &#8220;bad&#8221;</p>
+
+<p>Second one &#8216;is&#8217;</p>
+
+
+
+<p><span class="caps">ESCAPED</span> &#8220;bad&#8221;</p>
+
+<p>Third one &#8216;is&#8217;</p>
+
+<p><span class="caps">ESCAPED</span> &#8220;bad&#8221;</p>
+
+<p>Last one &#8216;is&#8217;</p>
+
+<p><span class="caps">ESCAPED</span> &#8220;good&#8221; test</p>'''
+    t = textile.Textile()
+    result = t.parse(test)
+    assert result == expect
+
+def test_github_pull_63():
+    """Forgot to set multiline_para to False"""
+    test = '''p.. First one 'is'
+
+ESCAPED "bad"
+
+bc.. {
+ First code BLOCK
+
+ {"JSON":'value'}
+}
+
+p.. Second one 'is'
+
+
+
+ESCAPED "bad"
+
+p.. Third one 'is'
+
+ESCAPED "bad"
+
+bc.. {
+ Last code BLOCK
+
+ {"JSON":'value'}
+}
+
+p.. Last one 'is'
+
+ESCAPED "good" test'''
+
+    expect = '''<p>First one &#8216;is&#8217;</p>
+
+<p><span class="caps">ESCAPED</span> &#8220;bad&#8221;</p>
+
+<pre><code>{
+ First code BLOCK
+
+ {&quot;JSON&quot;:&#39;value&#39;}
+}</code></pre>
+
+<p>Second one &#8216;is&#8217;</p>
+
+
+
+<p><span class="caps">ESCAPED</span> &#8220;bad&#8221;</p>
+
+<p>Third one &#8216;is&#8217;</p>
+
+<p><span class="caps">ESCAPED</span> &#8220;bad&#8221;</p>
+
+<pre><code>{
+ Last code BLOCK
+
+ {&quot;JSON&quot;:&#39;value&#39;}
+}</code></pre>
+
+<p>Last one &#8216;is&#8217;</p>
+
+<p><span class="caps">ESCAPED</span> &#8220;good&#8221; test</p>'''
+    t = textile.Textile()
+    result = t.parse(test)
+    assert result == expect
